{ lib, ... }: let
  tsHost = x: "http://${x}.hoki-porgy.ts.net";
  
  aliases = x: { serverAliases = x; };

  routes = [
    { 
      host = "warme.st"; 
      target = tsHost "honeydew"; 
      extra = aliases [ "colde.st" ]; 
    }
    { 
      host = "saerro.ps2.live"; 
      target = tsHost "durian"; 
      extra = aliases [ "agg.ps2.live" "metagame.ps2.live" ]; 
    }
    {
      host = "mx.sapphic.engineer";
      target = tsHost "mango";
      extra = aliases [ "i.mx.sapphic.engineer" ];
    }
    {
      host = "static-sites.foxxolay.net";
      target = tsHost "juniper";
      extra = aliases [ 
        "mekanoe.com" 
        "foxxolay.com" 
        "foxxolay.net" 
        "inaayoka.com" 
        "kat.cafe"
      ];
    }
    {
      host = "ml.colde.st";
      target = tsHost "lab-alpha"; 
    }
  ];

  proxyConfig = {
    forceSSL = true;
    useHTTP3 = true;
    useHTTP2 = true;
    enableACME = true;
  };

  virtualHosts = map (x: 
    lib.nameValuePair 
      x.host 
      ({ locations."/".proxyPass = x.target; } // proxyConfig // x.extra)
  ) routes;
in {
  imports = [
    ../../templates/proxmox-lxc.nix
    ../../server.nix
    ../../features/dns-cache.nix
    ../../features/nginx.nix
  ];

  networking.hostName = "ingress-proxy";
  system.stateVersion = "24.05"; 
  nixpkgs.hostPlatform = "x86_64-linux";

  services.nginx = {
    inherit virtualHosts;
    recommendedTlsSettings = true; 
  };
}
